package sun.nio.fs;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.io.IOException;
import java.nio.file.attribute.UserPrincipal;
import java.util.List;
import java.nio.file.attribute.AclFileAttributeView;

abstract class AbstractAclFileAttributeView implements AclFileAttributeView, DynamicFileAttributeView
{
    private static final String OWNER_NAME = "owner";
    private static final String ACL_NAME = "acl";
    
    AbstractAclFileAttributeView() {
    }
    
    @Override
    public final String name() {
        return "acl";
    }
    
    @Override
    public final void setAttribute(String str, Object o) throws IOException {
        if (str.equals("owner")) {
            this.setOwner((UserPrincipal)o);
            return;
        }
        if (str.equals("acl")) {
            this.setAcl((List)o);
            return;
        }
        throw new IllegalArgumentException("'" + this.name() + ":" + str + "' not recognized");
    }
    
    @Override
    public final Map<String, Object> readAttributes(String[] array) throws IOException {
        boolean n = false;
        boolean n2 = false;
        for (String str : array) {
            if (str.equals("*")) {
                n2 = true;
                n = true;
            }
            else if (str.equals("acl")) {
                n = true;
            }
            else if (str.equals("owner")) {
                n2 = true;
            }
            else {
                throw new IllegalArgumentException("'" + this.name() + ":" + str + "' not recognized");
            }
        }
        HashMap m = new HashMap(2);
        if (!(n == 0)) {
            m.put("acl", this.getAcl());
        }
        if (!(n2 == 0)) {
            m.put("owner", this.getOwner());
        }
        return Collections.unmodifiableMap(m);
    }
}
